Learn R Programming

ineq (version 0.2-8)

Ilocos: Income Metadata from Ilocos, Philippines

Description

Income metadata from surveys conducted by the Philippines' National Statistics Office.

Usage

data(Ilocos)

Arguments

source

National Statistics Office, Philippines: http://www.census.gov.ph/, where also the whole data set may be obtained.

Details

The data contains household income and metadata in one of the sixteen regions of the Philippines called Ilocos. The data comes from two of the NSO's surveys: the 1997 Family and Income and Expenditure Survey and the 1998 Annual Poverty Indicators Survey (APIS).

Since the APIS only has a six month reference period, the original data were rescaled using an adjustment factor from the quarterly GDP figures that can be obtained from the major sectors.