Learn R Programming

ineq (version 0.2-8)

pov: Poverty Measures

Description

computes the poverty of an (income) vector according to the specified poverty measure

Usage

pov(x, k, parameter = NULL,type = c("Watts", "Sen", "Foster"))

Watts(x,k) Sen(x,k) Foster(x,k,parameter=1)

Arguments

x
a vector containing at least non-negative elements
k
a constant giving the absolute poverty boundary
parameter
parameter of the poverty measure (if set to NULL the default parameter of the respective measure is used)
type
character string giving the measure used to compute poverty coefficient must be one of the strings in the default argument (the first character is sufficient). defaults to "Watts".

Value

  • the value of the poverty measure

Details

pov is just a wrapper for the poverty measures of Watts, Sen and Foster (Foster / Greer / Thorbecke). If parameter is set to NULL the default from the respective function is used.

Foster gives for parameter 1 the head count ratio and for parameter 2 the poverty gap ratio.

References

Buhong Zheng: Aggregate Poverty Measures, 1997, Journal of Economic Surveys Vol.11 No.2, 123-162. J E Foster: On Economic Poverty: A Survey Of Aggregate Measures, 1984, Advances in Econometrics Vol. 3, 215-251.

See Also

ineq, conc

Examples

Run this code
# generate vectors (of incomes)
x <- c(541, 1463, 2445, 3438, 4437, 5401, 6392, 8304, 11904, 22261)
y <- c(841, 2063, 2445, 3438, 4437, 5401, 6392, 8304, 11304, 21961)
# compute Watts index with poverty boundary 2000
pov(x, 2000)
pov(y, 2000)
# compute head count ratio with poverty boundary 2000
pov(x, 2000, parameter=1, type="Foster")
pov(y, 2000, parameter=1, type="Foster")

Run the code above in your browser using DataLab